==> kubernetes-model-core-5.0.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/VolumeNodeAffinityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class VolumeNodeAffinityBuilder extends VolumeNodeAffinityFluentImpl<VolumeNodeAffinityBuilder> implements VisitableBuilder<VolumeNodeAffinity,VolumeNodeAffinityBuilder> {

    VolumeNodeAffinityFluent<?> fluent;
    Boolean validationEnabled;

    public VolumeNodeAffinityBuilder() {
        this(true);
    }

    public VolumeNodeAffinityBuilder(Boolean validationEnabled) {
        this(new VolumeNodeAffinity(), validationEnabled);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent) {
        this(fluent, true);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new VolumeNodeAffinity(), validationEnabled);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent,VolumeNodeAffinity instance) {
        this(fluent, instance, true);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent,VolumeNodeAffinity instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withRequired(instance.getRequired()); 
        this.validationEnabled = validationEnabled; 
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinity instance) {
        this(instance,true);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinity instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withRequired(instance.getRequired()); 
        this.validationEnabled = validationEnabled; 
    }

    public VolumeNodeAffinity build() {
        VolumeNodeAffinity buildable = new VolumeNodeAffinity(fluent.getRequired());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        VolumeNodeAffinityBuilder that = (VolumeNodeAffinityBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/VolumeNodeAffinityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class VolumeNodeAffinityBuilder extends VolumeNodeAffinityFluentImpl<VolumeNodeAffinityBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<VolumeNodeAffinity,VolumeNodeAffinityBuilder> {

    VolumeNodeAffinityFluent<?> fluent;
    Boolean validationEnabled;

    public VolumeNodeAffinityBuilder() {
        this(true);
    }

    public VolumeNodeAffinityBuilder(Boolean validationEnabled) {
        this(new VolumeNodeAffinity(), validationEnabled);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent) {
        this(fluent, true);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new VolumeNodeAffinity(), validationEnabled);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent,VolumeNodeAffinity instance) {
        this(fluent, instance, true);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinityFluent<?> fluent,VolumeNodeAffinity instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withRequired(instance.getRequired()); 
        this.validationEnabled = validationEnabled; 
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinity instance) {
        this(instance,true);
    }

    public VolumeNodeAffinityBuilder(VolumeNodeAffinity instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withRequired(instance.getRequired()); 
        this.validationEnabled = validationEnabled; 
    }

    public VolumeNodeAffinity build() {
        VolumeNodeAffinity buildable = new VolumeNodeAffinity(fluent.getRequired());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        VolumeNodeAffinityBuilder that = (VolumeNodeAffinityBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
